<?php

/**
 * @file
 * Contains \Drupal\menu_trail_by_path\Path\BreadcrumbPath.
 */

namespace Drupal\menu_trail_by_path\Path;

use Drupal\Core\Breadcrumb\BreadcrumbBuilderInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;

class BreadcrumbPath implements PathInterface{
  /**
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * @var \Drupal\Core\Breadcrumb\BreadcrumbBuilderInterface
   */
  private $breadcrumbBuilder;

  public function __construct(RouteMatchInterface $route_match, BreadcrumbBuilderInterface $breadcrumb_builder) {
    $this->routeMatch        = $route_match;
    $this->breadcrumbBuilder = $breadcrumb_builder;
  }

  /**
   * @inheritdoc
   */
  public function getUrls() {
    $trail_urls = $this->getBreadcrumbUrls();
    if ($current_request_url = $this->getCurrentRequestUrl()) {
      $trail_urls[] = $current_request_url;
    }

    return $trail_urls;
  }

  /**
   * @return \Drupal\Core\Url|null
   */
  protected function getCurrentRequestUrl() {
    $route_name = $this->routeMatch->getRouteName();
    if ($route_name) {
      $route_parameters = $this->routeMatch->getRawParameters()->all();
      return new Url($route_name, $route_parameters);
    }

    return NULL;
  }

  /**
   * @return \Drupal\Core\Url[]
   */
  protected function getBreadcrumbUrls() {
    $breadcrumb_urls = [];
    $breadcrumb      = $this->breadcrumbBuilder->build($this->routeMatch);
    foreach ($breadcrumb->getLinks() as $breadcrumb_link) {
      $breadcrumb_urls[] = $breadcrumb_link->getUrl();
    }

    return $breadcrumb_urls;
  }
}
